@@ -3,7 +3,7 @@ use strict;
 
 package Jifty;
 
-our $VERSION = '0.60221';
+our $VERSION = '0.60321';
 
 =head1 NAME
 
@@ -56,10 +56,9 @@ probably a better place to start.
 
 =cut
 
-use Jifty::Everything;
-use UNIVERSAL::require;
 
 use base qw/Jifty::Object/;
+use Jifty::Everything;
 
 use vars qw/$HANDLE $CONFIG $LOGGER $DISPATCHER/;
 
@@ -104,12 +103,20 @@ sub new {
     # Load the configuration. stash it in ->config
     __PACKAGE__->config( Jifty::Config->new() );
 
+    # Now that we've loaded the configuration, we can remove the temporary 
+    # Jifty::DBI::Record baseclass for records and insert our "real" baseclass,
+    # which is likely Record::Cachable or Record::Memcached
+    pop @Jifty::Record::ISA;
+    Jifty::Util->require( Jifty->config->framework('Database')->{'RecordBaseClass'});
+    push @Jifty::Record::ISA, Jifty->config->framework('Database')->{'RecordBaseClass'};
+
     __PACKAGE__->logger( Jifty::Logger->new( $args{'logger_component'} ) );
+   # Get a classloader set up
+   Jifty::ClassLoader->new->require;
+
     __PACKAGE__->dispatcher(Jifty::Dispatcher->new());
     __PACKAGE__->handler(Jifty::Handler->new());
 
-   # Get a classloader set up
-   Jifty::ClassLoader->new->require;
 
    # Let's get the database rocking and rolling
    __PACKAGE__->setup_database_connection(%args);
