@@ -31,7 +31,7 @@ current region.
 
 =item prepend => PATH
 
-Add the given C<PATH> as a new fragment, just aftger the start of the
+Add the given C<PATH> as a new fragment, just after the start of the
 CSS selector given by C<element>, which defaults to the start of the
 current region.
 
@@ -86,7 +86,7 @@ fragment.
 
 =item effect_args => HASHREF
 
-A hashref of arguments to pass to the effect when it is creted.  These
+A hashref of arguments to pass to the effect when it is created.  These
 can be used to change the duration of the effect, for instance.
 
 =back
@@ -117,7 +117,7 @@ __PACKAGE__->mk_accessors(qw(onclick class key_binding id label tooltip));
 
 =head2 javascript
 
-Returns the javsscript necessary to make the events happen.
+Returns the javascript necessary to make the events happen.
 
 =cut
 
@@ -153,6 +153,8 @@ sub javascript {
             } elsif (exists $hook->{replace_with}) {
                 @args{qw/mode path region/} = ('Replace', $hook->{replace_with}, $hook->{region});
             } elsif (exists $hook->{refresh}) {
+                my $region = ref $hook->{refresh} ? $hook->{refresh} : Jifty->web->get_region($hook->{refresh});
+                warn "Can't find region ".$hook->{refresh} and next unless $region;
                 @args{qw/mode path region/} = ('Replace', $hook->{refresh}->path, $hook->{refresh});
             } elsif ((exists $hook->{refresh_self} and Jifty->web->current_region) or $hook->{args}) {
                 # If we just pass arguments, treat as a refresh_self
