@@ -19,7 +19,7 @@ sub render_widget {
         'type="submit"',
         'name="' . $self->input_name . '" ',
         'value="' . $self->label . '"',
-        $self->_widget_class,
+        $self->_widget_class('button'),
         $self->javascript,
         ' />',
         "\n"
